#[non_exhaustive]pub enum Request<'a> {
Destroy,
Ring {
surface: Option<WlSurface>,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Destroy
destroy the system bell object
Notify that the object will no longer be used.
This is a destructor, once sent this object cannot be used any longer.
Ring
ring the system bell
This requests rings the system bell on behalf of a client. How ringing the bell is implemented is up to the compositor. It may be an audible sound, a visual feedback of some kind, or any other thing including nothing.
The passed surface should correspond to a toplevel like surface role, or be null, meaning the client doesn’t have a particular toplevel it wants to associate the bell ringing with. See the xdg-shell protocol extension for a toplevel like surface role.
Implementations